@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Update;
 {
-  $Dist::Zilla::Plugin::GitHub::Update::VERSION = '0.29';
+  $Dist::Zilla::Plugin::GitHub::Update::VERSION = '0.30';
 }
 
 use strict;
@@ -43,7 +43,7 @@ Dist::Zilla::Plugin::GitHub::Update - Update a GitHub repo's info on release
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -148,9 +148,15 @@ sub release {
 
 =item C<repo>
 
-The name of the GitHub repository. By default the dist name (from dist.ini)
-is used. It can also be in the form C<user/repo> when it belongs to another
-GitHub user/organization.
+The name of the GitHub repository. By default the name will be extracted from
+the URL of the remote specified in the C<remote> option, and if that fails the
+dist name (from dist.ini) is used. It can also be in the form C<user/repo>
+when it belongs to another GitHub user/organization.
+
+=item C<remote>
+
+The name of the Git remote pointing to the GitHub repository (C<"origin"> by
+default). This is used when trying to guess the repository name.
 
 =item C<cpan>
 
